@@ -33,6 +33,8 @@
 #endif
 
 /* AutoInit dependencies.  */
+#include "vtkFiltersGeneralModule.h"
 #include "vtkRenderingContext2DModule.h"
+#include "vtkRenderingCoreModule.h"
 
 #endif
