@@ -32,7 +32,6 @@
 # define VTKIOAMR_NO_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersAMRModule.h"
+
 
 #endif
