@@ -33,11 +33,16 @@
 #endif
 
 /* AutoInit dependencies.  */
-#include "vtkRenderingAnnotationModule.h"
-#include "vtkRenderingContext2DModule.h"
 #include "vtkRenderingCoreModule.h"
-#include "vtkRenderingFreeTypeModule.h"
-#include "vtkRenderingLabelModule.h"
-#include "vtkRenderingOpenGL2Module.h"
+#include "vtkRenderingGL2PSModule.h"
+
+/* AutoInit implementations.  */
+#if defined(vtkIOExport_INCLUDE)
+# include vtkIOExport_INCLUDE
+#endif
+#if defined(vtkIOExport_AUTOINIT)
+# include "vtkAutoInit.h"
+VTK_AUTOINIT(vtkIOExport)
+#endif
 
 #endif
