@@ -32,9 +32,6 @@
 # define VTKINFOVISLAYOUT_NO_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersModelingModule.h"
-#include "vtkImagingHybridModule.h"
-#include "vtkInfovisCoreModule.h"
+
 
 #endif
